==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/PodDNSConfigOptionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodDNSConfigOptionBuilder extends io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluentImpl<io.fabric8.kubernetes.api.model.PodDNSConfigOptionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PodDNSConfigOption,io.fabric8.kubernetes.api.model.PodDNSConfigOptionBuilder>{
  public PodDNSConfigOptionBuilder() {
    this(false);
  }
  public PodDNSConfigOptionBuilder(java.lang.Boolean validationEnabled) {
    this(new PodDNSConfigOption(), validationEnabled);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodDNSConfigOption(), validationEnabled);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,io.fabric8.kubernetes.api.model.PodDNSConfigOption instance) {
    this(fluent, instance, false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,io.fabric8.kubernetes.api.model.PodDNSConfigOption instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOption instance) {
    this(instance,false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOption instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PodDNSConfigOption build() {
    PodDNSConfigOption buildable = new PodDNSConfigOption(fluent.getName(),fluent.getValue());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodDNSConfigOptionBuilder that = (PodDNSConfigOptionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/PodDNSConfigOptionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodDNSConfigOptionBuilder extends io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluentImpl<io.fabric8.kubernetes.api.model.PodDNSConfigOptionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PodDNSConfigOption,io.fabric8.kubernetes.api.model.PodDNSConfigOptionBuilder>{
  public PodDNSConfigOptionBuilder() {
    this(false);
  }
  public PodDNSConfigOptionBuilder(java.lang.Boolean validationEnabled) {
    this(new PodDNSConfigOption(), validationEnabled);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodDNSConfigOption(), validationEnabled);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,io.fabric8.kubernetes.api.model.PodDNSConfigOption instance) {
    this(fluent, instance, false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent,io.fabric8.kubernetes.api.model.PodDNSConfigOption instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOption instance) {
    this(instance,false);
  }
  public PodDNSConfigOptionBuilder(io.fabric8.kubernetes.api.model.PodDNSConfigOption instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PodDNSConfigOptionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PodDNSConfigOption build() {
    PodDNSConfigOption buildable = new PodDNSConfigOption(fluent.getName(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodDNSConfigOptionBuilder that = (PodDNSConfigOptionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
